API reference
=============

:mod:`pyimgren` module
----------------------

.. module:: pyimgren

This module imports :py:class:`pyimgren.renamer.Renamer`
and the function :py:func:`pyimgren.renamer.nls_init`.
It also defines the following constants:

.. data:: __name__

        the name of the package (``pyimgren``)

.. data:: __version__

        the current version of the package (|release|)

:mod:`pyimgren.renamer` module
------------------------------

.. automodule:: pyimgren.renamer
    :members:
    :show-inheritance:
